@@ -72,12 +72,12 @@ class Registry:
         file_path = config_path or self.config_path
 
         if file_type is None:
-            _, config_ext = path.splitext(config_path)
+            _, config_ext = path.splitext(file_path)
             config_type = config_ext[1:]
         else:
             config_type = file_type
 
-        with open(config_path or self.config_path) as config_file:
+        with open(file_path or self.config_path) as config_file:
             if config_type == 'json':
                 self.configuration = json.load(config_file)
             elif config_type == 'yaml':
